@@ -1,7 +1,8 @@
 from deepctr.layers import custom_objects
 from deepctr.layers.utils import reduce_sum
 
-from .core import PoolingLayer, Similarity, LabelAwareAttention, CapsuleLayer, SampledSoftmaxLayer, EmbeddingIndex
+from .core import PoolingLayer, Similarity, LabelAwareAttention, CapsuleLayer, SampledSoftmaxLayer, EmbeddingIndex, \
+    MaskUserEmbedding
 from .interaction import DotAttention, ConcatAttention, SoftmaxWeightedSum, AttentionSequencePoolingLayer, \
     SelfAttention, \
     SelfMultiHeadAttention, UserAttention
@@ -23,7 +24,8 @@ _custom_objects = {'PoolingLayer': PoolingLayer,
                    'SelfAttention': SelfAttention,
                    'SelfMultiHeadAttention': SelfMultiHeadAttention,
                    'UserAttention': UserAttention,
-                   'DynamicMultiRNN': DynamicMultiRNN
+                   'DynamicMultiRNN': DynamicMultiRNN,
+                   'MaskUserEmbedding': MaskUserEmbedding
                    }
 
 custom_objects = dict(custom_objects, **_custom_objects)
